---------------------------------------------------------------------------------------------------------------------
--文件名:	WorkskillSys.lua
--版  权:	(C)盛游
--创建人:	Linhongwei
--日  期:	2013.12.12
--版  本:	1.0
--描  述:	炼器系统。
--			主要功能：
--			1.所有炼器的消息码从这里统一收发，这样做的一个好处是以后可以加些通用的判断流程。比如发送炼器消息码的时候可
--			以补个客户端的当前时间等。
--			2.定制一些通用函数供子模块使用，比如背包里有没有符合某炼器技能的道具。
----------------------------------------------------------------------------------------------------------------------
--*1 定义模块名******************************************************--
module("WorkskillSys",package.seeall)
--*定义模块名 end****************************************************--


--*2 常量************************************************************--
local modName = "WorkskillSys"

--旧炼器系统宝石镶嵌，七彩宝石和普通宝石的互斥判断
local oldGemInlayCfg ={
	{gemType = 11,excludeGemTypes ={1,5,9,10,},},
	{gemType = 12,excludeGemTypes ={2,6,7,8,},},
	{gemType = 13,excludeGemTypes ={1,2,3,4,},},
}
--*常量 end**********************************************************--


--*3 变量************************************************************--
--子模块表
subModTable = subModTable or {}
--*变量 end**********************************************************--


--*4 函数实现********************************************************--
--添加子模块
function AddSubMod(subMod)
	--检错下
	if type(subMod) ~= "table" or subMod.modName == nil or subMod.MsgHandler == nil then
		API_TraceError("WorkskillSys error.AddSubMod() subMod format is wrong:".. cjson.encode(subMod));
	end
	
	subModTable[subMod.modName] = subMod
end
--接网络消息
function MsgHandler(msg)
	--检错下
	if subModTable[msg.workskillType] == nil then
		API_Trace("WorkskillSys error.MsgHandler() unknown workskill type:"..msg.workskillType);
		return
	end
	
	if(msg.msg_code=="Finish") then --炼器完成回送消息
		--这里可以做些通用处理，比如限制下玩家等级
		--未实现
	end
	
	--传递给子模块,由子模块做真正的处理
	subModTable[msg.workskillType].MsgHandler(msg)
end

--发网络消息，子模块不要自己发，通过这里发或者通过下边的常用消息
function MsgDispatch(msg,subModName)
	--检错下
	if subModTable[subModName] == nil then
		API_Trace("WorkskillSys error.MsgDispatch() unknown workskill type:"..subModName);
		return
	end

	msg.module   		= modName
	msg.workskillType 	= subModName
	local jsonstr = cjson.encode(msg)
	g_pGlobal:SendScriptMsg(jsonstr)
end

--旧的炼器系统里的宝石镶嵌暴露个接口，可以控制能否镶嵌
function OldGemInlayExt(actorID,gemId1,gemId2,gemId3,gemType1,gemType2,gemType3)
--API_Trace(" "..gemId1.." "..gemId2.." "..gemId3.." "..gemType1.." "..gemType2.." "..gemType3)
	if gemId1 ~= 0 then
		for k,v in pairs(oldGemInlayCfg) do
			if v.gemType == gemType1 then
				for k2,v2 in pairs(v.excludeGemTypes) do
					if gemType2 == v2 or gemType3 == v2 then
						API_ShowSystemMessage(enSysMsgDisplayType_Float, "多彩宝石不与拥有相同属性的普通宝石共存")
						return false
					end
				end
			end
		end
	end
	
	if gemId2 ~= 0 then
		for k,v in pairs(oldGemInlayCfg) do
			if v.gemType == gemType2 then
				for k2,v2 in pairs(v.excludeGemTypes) do
					if gemType1 == v2 or gemType3 == v2 then
						API_ShowSystemMessage(enSysMsgDisplayType_Float, "多彩宝石不与拥有相同属性的普通宝石共存")
						return false
					end
				end
			end
		end
	end
	
	if gemId3 ~= 0 then
		for k,v in pairs(oldGemInlayCfg) do
			if v.gemType == gemType3 then
				for k2,v2 in pairs(v.excludeGemTypes) do
					if gemType1 == v2 or gemType2 == v2 then
						API_ShowSystemMessage(enSysMsgDisplayType_Float, "多彩宝石不与拥有相同属性的普通宝石共存")
						return false
					end
				end
			end
		end
	end
	
	
	return true
end
--*函数实现 end******************************************************--


--*5 加载脚本的时候执行**********************************************--
--注册网络消息
api_reg_module_msg_handler("WorkskillSys",MsgHandler)

rawset(_G,"WorkskillSysOldGemInlayExt",OldGemInlayExt)--把函数设置成全局的
--*加载脚本的时候执行 end********************************************--


--切记自己加载完才加载子模块。这样保证自己的功能加载完再把初始化的事情交给子模块自己，Linhongwei
--*6加载子模块*******************************************************--
API_LoadScript("Data\\Scp\\Lua\\window\\workskill\\ColorfulGemMake.lua")	--七彩宝石打造
API_LoadScript("Data\\Scp\\Lua\\window\\workskill\\EquipDecompose.lua")	--装备分解
--*加载子模块 end****************************************************--

